@@ -21,4 +21,9 @@ def detect_checkbox(context, field):
     else:
         context['is_checkbox'] = False
     
-    return ''
\ No newline at end of file
+    return ''
+    
+    
+@register.inclusion_tag('coffee/partial/form.html')
+def render_form(form):
+    return {'form': form}
\ No newline at end of file
